@@ -14,8 +14,6 @@
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
 ### END LICENSE
 
-from locale import gettext as _
-
 import logging
 logger = logging.getLogger('typecatcher')
 
@@ -27,7 +25,4 @@ class AboutTypeCatcherDialog(AboutDialog):
     
     def finish_initializing(self, builder): # pylint: disable=E1002
         """Set up the about dialog"""
-        super(AboutTypeCatcherDialog, self).finish_initializing(builder)
-
-        # Code for other initialization actions should be added here.
-
+        super(AboutTypeCatcherDialog, self).finish_initializing(builder)
\ No newline at end of file
